@@ -308,4 +308,19 @@ def xml_upload(client, tbid, rid: int, fid: int, file: any, filename: str) -> QB
         return res
     except Exception as e:
         res.ok = False
-        res.text = str(e)
\ No newline at end of file
+        res.text = str(e)
+
+
+def split_list_into_chunks(array: list, chunk_size: int):
+    """
+        splits a list into a list of lists of specified chunk size
+    """
+    return_array = []
+
+    for i in range(0, len(array), chunk_size):
+        chunk = array[i:i + chunk_size]
+        return_array.append(chunk)
+
+    return return_array
+
+
